を惟む

食物繊維はごぼう※の約1.5倍
カリウムはぼうれん草※の約2.1倍
※可食部100gあたり/日本食品標準成分表
2020年版(八訂)」参照

栄養成分表示(1袋50gあたり)
エネルギー | 101kcal
たんぱく質 | 13.6g
一質 脂 | 0.2g
炭水化物 | 13.6g
糖 質 | 8.8g
食物繊維 | 4.8g
食塩相当量 | 11.9g
カリウム | 523mg
カルシウム | 83mg

901159 304208
4

●お客様相談室
0120-041-965
受付9:00~17:00
(土·日·祝日を除く)

名 称 | 塩こんぶ
原材料名 | 昆布(北海道産)、醤油(大豆·小麦 を含む)、食塩、醤油加工品(大豆 小麦を含む)/調味料(アミノ酸 等)、甘味料(ソルビトール、甘草), 増粘多糖類
内容量 | 50g
賞味期限 | 表面下部に記載
保存方法 | 直射日光、高温多湿を避け常温で 保存してください。
製造者 | 株式会社くらこん 〒573-1132 大阪府枚方市招提田近2-1-3 製造所固有記号は賞味期限の後に記載

<食物アレルギーをお持ちのお客様へ>
食品表示法によるアレルギー物質を含む食品28品目について、以下に記載いたしました。

※1 この商品に含まれる全ての小麦は醤油由来です。
小麦・大豆
●使用している食品
※2 同じ製造ラインで、乳成分を含む製品を製造しています。
えび・かに・くるみ・そぱ・卵・乳成分(上記※2参照)・湾だも(^_^)・アー
モンド・あわび・いか・いくら・オレンジ・ガンューエッツ・キライフルーツ・牛肉・
●使用していない食品
ごま・さけ・さば・鶏肉・バナナ・豚肉・まつたけ・もも・やまいも・りんご・セラチン